@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
+
 
 import sphinx_py3doc_enhanced_theme
 
@@ -20,7 +20,7 @@ project = 'django-redisboard'
 year = '2011-2022'
 author = 'Ionel Cristian Mărieș'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '5.0.0'
+version = release = '6.0.0'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -28,10 +28,10 @@ extlinks = {
     'issue': ('https://github.com/ionelmc/django-redisboard/issues/%s', '#'),
     'pr': ('https://github.com/ionelmc/django-redisboard/pull/%s', 'PR #'),
 }
-html_theme = "sphinx_py3doc_enhanced_theme"
+html_theme = 'sphinx_py3doc_enhanced_theme'
 html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
 html_theme_options = {
-    'githuburl': 'https://github.com/ionelmc/django-redisboard/'
+    'githuburl': 'https://github.com/ionelmc/django-redisboard/',
 }
 
 html_use_smartypants = True
