@@ -1,35 +1,41 @@
 import re
+from collections import OrderedDict
 from datetime import datetime
 from datetime import timedelta
 
 import redis
 from django.conf import settings
 from django.core.exceptions import ValidationError
-from django.core.validators import MaxValueValidator
-from django.core.validators import MinValueValidator
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from .utils import PY3
 from .utils import cached_property
 
-try:
-    from django.utils.datastructures import SortedDict as OrderedDict
-except ImportError:
-    from collections import OrderedDict
-
-REDISBOARD_DETAIL_FILTERS = [re.compile(name) for name in getattr(settings, 'REDISBOARD_DETAIL_FILTERS', (
-    'aof_enabled', 'bgrewriteaof_in_progress', 'bgsave_in_progress',
-    'changes_since_last_save', 'db.*', 'last_save_time', 'multiplexing_api',
-    'total_commands_processed', 'total_connections_received', 'uptime_in_days',
-    'uptime_in_seconds', 'vm_enabled', 'redis_version'
-))]
-REDISBOARD_DETAIL_TIMESTAMP_KEYS = getattr(settings, 'REDISBOARD_DETAIL_TIMESTAMP_KEYS', (
-    'last_save_time',
-))
-REDISBOARD_DETAIL_SECONDS_KEYS = getattr(settings, 'REDISBOARD_DETAIL_SECONDS_KEYS', (
-    'uptime_in_seconds',
-))
+REDISBOARD_DETAIL_FILTERS = [
+    re.compile(name)
+    for name in getattr(
+        settings,
+        'REDISBOARD_DETAIL_FILTERS',
+        (
+            'aof_enabled',
+            'bgrewriteaof_in_progress',
+            'bgsave_in_progress',
+            'changes_since_last_save',
+            'db.*',
+            'last_save_time',
+            'multiplexing_api',
+            'total_commands_processed',
+            'total_connections_received',
+            'uptime_in_days',
+            'uptime_in_seconds',
+            'vm_enabled',
+            'redis_version',
+        ),
+    )
+]
+REDISBOARD_DETAIL_TIMESTAMP_KEYS = getattr(settings, 'REDISBOARD_DETAIL_TIMESTAMP_KEYS', ('last_save_time',))
+REDISBOARD_DETAIL_SECONDS_KEYS = getattr(settings, 'REDISBOARD_DETAIL_SECONDS_KEYS', ('uptime_in_seconds',))
 
 REDISBOARD_SLOWLOG_LEN = getattr(settings, 'REDISBOARD_SLOWLOG_LEN', 10)
 
@@ -48,14 +54,18 @@ def prettify(key, value):
         return key, value
 
 
+def validate_url(value):
+    try:
+        redis.connection.parse_url(value)
+    except Exception as exc:
+        raise ValidationError(str(exc))
+
+
 class RedisServer(models.Model):
     class Meta:
-        unique_together = ('hostname', 'port')
         verbose_name = _("Redis Server")
         verbose_name_plural = _("Redis Servers")
-        permissions = (
-            ("can_inspect", "Can inspect redis servers"),
-        )
+        permissions = (("can_inspect", "Can inspect redis servers"),)
 
     label = models.CharField(
         _('Label'),
@@ -63,51 +73,42 @@ class RedisServer(models.Model):
         blank=True,
         null=True,
     )
-
-    hostname = models.CharField(
-        _("Hostname"),
+    url = models.CharField(
+        _("URL"),
         max_length=250,
-        help_text=_('This can also be the absolute path to a redis socket')
+        unique=True,
+        help_text=_(
+            '<a href="https://www.iana.org/assignments/uri-schemes/prov/redis">IANA-compliant</a> URL. Examples: <pre>'
+            'redis://[[username]:[password]]@localhost:6379/0\n'
+            'rediss://[[username]:[password]]@localhost:6379/0\n'
+            'unix://[[username]:[password]]@/path/to/socket.sock?db=0</pre>'
+        ),
+        validators=[validate_url],
+    )
+    password = models.CharField(
+        _("Password"), max_length=250, null=True, blank=True, help_text=_('You can also specify the password here (the field is masked).')
     )
-
-    port = models.IntegerField(_("Port"), validators=[
-        MaxValueValidator(65535), MinValueValidator(1)
-    ], default=6379, blank=True, null=True)
-    password = models.CharField(_("Password"), max_length=250,
-                                null=True, blank=True)
 
     sampling_threshold = models.IntegerField(
         _("Sampling threshold"),
         default=1000,
-        help_text=_("Number of keys after which only a sample (of random keys) is shown on the inspect page.")
+        help_text=_("Number of keys after which only a sample (of random keys) is shown on the inspect page."),
     )
     sampling_size = models.IntegerField(
         _("Sampling size"),
         default=200,
-        help_text=_("Number of random keys shown when sampling is used. Note that each key translates to a RANDOMKEY call in redis.")
+        help_text=_("Number of random keys shown when sampling is used. Note that each key translates to a RANDOMKEY call in redis."),
     )
 
-    def clean(self):
-        if not self.hostname.startswith('/') and not self.port:
-            raise ValidationError(_('Please provide either a hostname AND a port or the path to a redis socket'))
-
     @cached_property
     def connection(self):
-        if self.hostname.startswith('/'):
-            unix_socket_path = self.hostname
-            hostname = None
-        else:
-            hostname = self.hostname
-            unix_socket_path = None
-        return redis.Redis(
-            host=hostname,
-            port=self.port,
-            password=self.password,
-            unix_socket_path=unix_socket_path,
-            socket_timeout=REDISBOARD_SOCKET_TIMEOUT,
-            socket_connect_timeout=REDISBOARD_SOCKET_CONNECT_TIMEOUT,
-            socket_keepalive=REDISBOARD_SOCKET_KEEPALIVE,
-            socket_keepalive_options=REDISBOARD_SOCKET_KEEPALIVE_OPTIONS,
+        return redis.StrictRedis(
+            single_connection_client=True,
+            connection_pool=redis.ConnectionPool.from_url(
+                self.url,
+                password=self.password,
+                retry_on_timeout=True,
+            ),
         )
 
     @connection.deleter
@@ -124,10 +125,7 @@ class RedisServer(models.Model):
             return {
                 'status': 'UP',
                 'details': info,
-                'memory': "%s (peak: %s)" % (
-                    info['used_memory_human'],
-                    info.get('used_memory_peak_human', 'n/a')
-                ),
+                'memory': "%s (peak: %s)" % (info['used_memory_human'], info.get('used_memory_peak_human', 'n/a')),
                 'clients': info['connected_clients'],
                 'brief_details': OrderedDict(
                     prettify(k, v)
@@ -159,18 +157,11 @@ class RedisServer(models.Model):
                 'slowlog_len': 0,
             }
 
-    def __unicode__(self):
+    def __str__(self):
         if self.label:
-            label = '%s (%%s)' % self.label
+            return f'{self.label} ({self.url})'
         else:
-            label = '%s'
-
-        if self.port:
-            label = label % ('%s:%s' % (self.hostname, self.port))
-        else:
-            label = label % self.hostname
-
-        return label
+            return self.url
 
     def slowlog_len(self):
         try:
@@ -178,7 +169,7 @@ class RedisServer(models.Model):
         except redis.exceptions.ConnectionError:
             return 0
 
-    def slowlog_get(self, limit=REDISBOARD_SLOWLOG_LEN):
+    def slowlog_get(self):
         try:
             for slowlog in self.connection.slowlog_get(REDISBOARD_SLOWLOG_LEN):
                 yield dict(
