@@ -1,8 +1,5 @@
-from __future__ import print_function
-
 import os
 import re
-import tempfile
 import time
 
 import psutil as psutil
@@ -13,27 +10,13 @@ from process_tests import wait_for_strings
 
 from redisboard.models import RedisServer
 
-TIMEOUT = int(os.getenv('TEST_TIMEOUT', 2))
-
-
-@pytest.fixture(scope="module")
-def redis_process():
-    socket_path = tempfile.mktemp('.sock')
-    try:
-        with TestProcess('redis-server', '--port', '0', '--unixsocket', socket_path) as process:
-            wait_for_strings(process.read, TIMEOUT, "Running")
-            yield socket_path
-    finally:
-        try:
-            os.unlink(socket_path)
-        except Exception:
-            pass
+TIMEOUT = int(os.getenv('TEST_TIMEOUT', 10))
 
 
 @pytest.fixture
-def redis_server(redis_process, db):
+def redis_server(redis_server, db):
     server = RedisServer.objects.create(
-        hostname=redis_process,
+        url=f'unix:///{redis_server}',
     )
     c = server.connection
     c.set('str', 'bar')
@@ -43,13 +26,16 @@ def redis_server(redis_process, db):
     c.hset('hash', 'foo', 'bar')
     c.lpush('list', 'foo', 'bar', 'foobar')
     c.zadd('sorted-set', {'foo': 1, 'b': 2})
-    c.eval("""
+    c.eval(
+        """
         local c = 0
         while c < 1000000 do
             redis.call('get', 'str')
             c = c + 1
         end
-    """, 0)
+    """,
+        0,
+    )
     yield server
 
 
@@ -60,8 +46,7 @@ def test_changelist(admin_client, redis_server):
     content = response.content.decode('utf-8')
     assert '>UP</td>' in content
     assert '<dt>redis_version</dt>' in content
-    assert '<a href="/redisboard/redisserver/{:d}/inspect/">Inspect</a>'.format(
-        redis_server.pk) in content
+    assert '<a href="/redisboard/redisserver/{:d}/inspect/">Inspect</a>'.format(redis_server.pk) in content
 
 
 @pytest.mark.django_db
@@ -74,23 +59,17 @@ def test_inspect(admin_client, redis_server):
     assert '<td>UP</td>' in content
     assert '<td>redis_version</td>' in content
 
-    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=set&db=0">set</a>'.format(
-        redis_server.pk) in content
-    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=str&db=0">str</a>'.format(
-        redis_server.pk) in content
-    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=hash&db=0">hash</a>'.format(
-        redis_server.pk) in content
-    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=list&db=0">list</a>'.format(
-        redis_server.pk) in content
-    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=sorted-set&db=0">sorted-set</a>'.format(
-        redis_server.pk) in content
+    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=set&db=0">set</a>'.format(redis_server.pk) in content
+    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=str&db=0">str</a>'.format(redis_server.pk) in content
+    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=hash&db=0">hash</a>'.format(redis_server.pk) in content
+    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=list&db=0">list</a>'.format(redis_server.pk) in content
+    assert '<a href="/redisboard/redisserver/{:d}/inspect/?key=sorted-set&db=0">sorted-set</a>'.format(redis_server.pk) in content
 
 
 @pytest.mark.django_db
 @pytest.mark.parametrize("key", ["set", "str", "hash", "list", "sorted-set"])
 def test_key_details(admin_client, redis_server, key):
-    response = admin_client.get(
-        '/redisboard/redisserver/{:d}/inspect/?key={}'.format(redis_server.pk, key))
+    response = admin_client.get('/redisboard/redisserver/{:d}/inspect/?key={}'.format(redis_server.pk, key))
     print(response)
     content = response.content.decode('utf-8')
     assert '<h2>Key data: {}</h2>'.format(key) in content
@@ -112,12 +91,15 @@ def test_cli(entrypoint, tmpdir):
                     break
         if port is None:
             pytest.fail("Didn't find the listen port!")
-        session = requests.Session()
-        resp = session.get('http://127.0.0.1:%s/' % port)
-        csrftoken, = re.findall('name=[\'"]csrfmiddlewaretoken[\'"] value=[\'"](.*?)[\'"]', resp.text)
-        resp = session.post('http://127.0.0.1:%s/login/?next=/redisboard/redisserver/' % port, data={
-            'csrfmiddlewaretoken': csrftoken,
-            'username': 'redisboard',
-            'password': 'foobar',
-        })
-        assert '<a href="/redisboard/redisserver/1/inspect/"' in resp.text
+        with requests.Session() as session:
+            resp = session.get('http://127.0.0.1:%s/' % port)
+            (csrftoken,) = re.findall('name=[\'"]csrfmiddlewaretoken[\'"] value=[\'"](.*?)[\'"]', resp.text)
+            resp = session.post(
+                'http://127.0.0.1:%s/login/?next=/redisboard/redisserver/' % port,
+                data={
+                    'csrfmiddlewaretoken': csrftoken,
+                    'username': 'redisboard',
+                    'password': 'foobar',
+                },
+            )
+            assert '<a href="/redisboard/redisserver/1/inspect/"' in resp.text
